@@ -11,11 +11,11 @@
 
 
 (** The main printing function. {!print} uses the rel-context
-    to rename the variables, and rebuilds raw Coq terms (for the given
+    to rename the variables, and rebuilds raw Rocq terms (for the given
     context, and the terms in the environment). In order to do so, it
     requires the information gathered by the {!Theory.Trans} module.*)
 val print :
-  Coq.Relation.t ->
+  Rocq.Relation.t ->
   Theory.Trans.ir ->
   (int * Matcher.Terms.t * Matcher.Subst.t Search_monad.m) Search_monad.m ->
   EConstr.rel_context  ->
